# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
from .string_or_number import StringOrNumber
import typing_extensions
from ...base_types.types.custom_field_value import CustomFieldValue
from ...core.serialization import FieldMetadata
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class ResolutionAttributes(UniversalBaseModel):
    identifier: typing.Optional[typing.List[StringOrNumber]] = None
    name: typing.Optional[typing.List[str]] = None
    country: typing.Optional[typing.List[str]] = None
    address: typing.Optional[typing.List[str]] = None
    date_of_birth: typing.Optional[typing.List[str]] = None
    contact: typing.Optional[typing.List[StringOrNumber]] = None
    type: typing.Optional[typing.List[str]] = None
    city: typing.Optional[typing.List[str]] = None
    state: typing.Optional[typing.List[str]] = None
    custom_field_name: typing_extensions.Annotated[
        typing.Optional[CustomFieldValue], FieldMetadata(alias="custom_{field name}")
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
