# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
from .ontology_base_filters import OntologyBaseFilters
import typing
from .ontology_region import OntologyRegion
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class GetOntologyRegionsResponse(UniversalBaseModel):
    """
    Examples
    --------
    from sayari.ontology import (
        GetOntologyRegionsResponse,
        OntologyBaseFilters,
        OntologyRegion,
    )

    GetOntologyRegionsResponse(
        filters=OntologyBaseFilters(
            id=["usa_&_canada"],
        ),
        data=[
            OntologyRegion(
                id="usa_&_canada",
                label="Usa & Canada",
            )
        ],
        total_count=1234,
    )
    """

    filters: OntologyBaseFilters
    data: typing.List[OntologyRegion]
    total_count: int

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
