# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
from ...generated_types.types.identifier_type import IdentifierType
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import typing
import pydantic


class OntologyIdentifier(UniversalBaseModel):
    id: IdentifierType
    label: str
    comment: str
    regex: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
